@@ -6,7 +6,9 @@ class Debian(Packages):
         setuptools = 'python3-setuptools',
         pip        = 'python3-pip',
         venv       = 'python3-venv',
+        pyopenssl  = 'python3-openssl',
         sqlite     = 'sqlite3',
+        ruby_dev   = 'ruby-dev',
     )
 
 
@@ -20,7 +22,7 @@ class FreeBSD_12(Packages):
 
 class FreeBSD_13(Packages):
     pkg = dict(
-        setuptools = 'py37-setuptools',
-        pip        = 'py37-pip',
+        setuptools = 'py38-setuptools',
+        pip        = 'py38-pip',
         sqlite     = 'sqlite3',
     )
